src.MEDS\_tabular\_automl.generate\_summarized\_reps
====================================================

.. automodule:: src.MEDS_tabular_automl.generate_summarized_reps







   .. rubric:: Functions

   .. autosummary::

      aggregate_matrix
      compute_agg
      generate_summary
      get_rolling_window_indicies
      sparse_aggregate
